@@ -5,7 +5,7 @@ c Licensed under the GPL -- www.gpl.org/licenses/gpl.html
  
 
        subroutine expfn(n,d2, par)
-       real*8 d2(n), par(1)
+       double precision d2(n), par(1)
        integer n
 
          do 5 k =1,n
